@@ -1,4 +1,4 @@
-`plspm` <-
+plspm <-
 function(x, inner.mat, sets, modes=NULL, scheme="centroid", 
                   scaled=TRUE, boot.val=FALSE, br=NULL, plsr=FALSE)
 {
@@ -14,7 +14,7 @@ function(x, inner.mat, sets, modes=NULL, scheme="centroid",
     # scaled: a logical value indicating whether scale data is performed
     # boot.val:a logical value indicating whether bootstrap validation is done 
     # br: an integer indicating the number of bootstraps resamples, used 
-    #     only when boot.val=TRUE, (50 <= br <= 500)
+    #     only when boot.val=TRUE, (100 <= br <= 1000)
     # plsr: a logical value for calculating path coeffs by pls-regression
     # ===========================================================================
 
@@ -59,7 +59,7 @@ function(x, inner.mat, sets, modes=NULL, scheme="centroid",
         if (modes[i]!="A" && modes[i]!="B") modes[i]<-"A"
     if (!is.na(pmatch(scheme, "centroid"))) 
         scheme <- "centroid"
-    SCHEMES <- c("centroid", "factor", "path")
+    SCHEMES <- c("centroid", "factor")
     scheme <- pmatch(scheme, SCHEMES)
     if (is.na(scheme)) {
         warning("Invalid argument 'scheme'. Default 'scheme=centroid' is used.")   
@@ -76,7 +76,7 @@ function(x, inner.mat, sets, modes=NULL, scheme="centroid",
     if (boot.val) {
         if (!is.null(br)) {        
             if (mode(br)!="numeric" || length(br)!=1 || (br%%1)!=0 ||
-                br<50 || br>500) {
+                br<100 || br>1000) {
                 warning("Invalid argument 'br'. Default 'br=100' is used.")   
                 br <- 100
             } 
@@ -110,40 +110,36 @@ function(x, inner.mat, sets, modes=NULL, scheme="centroid",
     }
     dimnames(DM) <- list(rownames(x), mvs.names)
     # apply the selected scaling
-    if(scaled) X=scale(DM) else X=scale(DM, scale=FALSE)
+    if (scaled) {
+        sd.X <- sqrt((nrow(DM)-1)/nrow(DM)) * apply(DM, 2, sd)
+        X <- scale(DM, scale=sd.X)
+    } else {
+        X <- scale(DM, scale=FALSE)
+    }
+    dimnames(X) <- list(rownames(x), mvs.names)
+
     # ==================== Stage 1: Iterative procedure ==================
-    out.ws <- pls.weights(X, IDM, blocks, modes, scheme)
+    out.ws <- .pls.weights(X, IDM, blocks, modes, scheme)
     if (is.null(out.ws)) stop("The pls algorithm is non convergent") 
     out.weights <- round(out.ws[[1]], 4)
     cor.XY <- cor(X, X%*%out.ws[[2]])
     w.sig <- rep(NA,lvs)
     for (k in 1:lvs) 
          w.sig[k] <- ifelse(sum(sign(cor.XY[which(blocklist==k),k]))<=0,-1,1)
-    if (scaled) {
-        Y.lvs <- X %*% out.ws[[2]] %*% diag(w.sig,lvs,lvs)
-        Z.lvs <- Y.lvs
-    } else
-    {   # expressing LVs in scale of MVs
+    Z.lvs <- X %*% out.ws[[2]] %*% diag(w.sig,lvs,lvs)
+    Y.lvs <- Z.lvs
+    if (!scaled) 
         Y.lvs <- DM %*% out.ws[[2]] %*% diag(w.sig,lvs,lvs)
-        mv.ran <- range(DM)
-        lv.ran <- range(Y.lvs)
-        Z.lvs <- (mv.ran[2]-mv.ran[1])/(lv.ran[2]-lv.ran[1]) * Y.lvs
-        if (range(Z.lvs)[2] > mv.ran[2]) 
-            Z.lvs <- Z.lvs - (range(Z.lvs)[2]-mv.ran[2])
-        if (range(Z.lvs)[2] < mv.ran[2])        
-            Z.lvs <- Z.lvs + (mv.ran[1] - range(Z.lvs)[1]) 
-        Z.lvs <- round(Z.lvs, 4)
-    }
     dimnames(Y.lvs) <- list(rownames(X), lvs.names)
     dimnames(Z.lvs) <- list(rownames(X), lvs.names)
     # ============ Stage 2: Path coefficients and total effects ==========
-    pathmod <- pls.paths(IDM, Y.lvs, plsr)
+    pathmod <- .pls.paths(IDM, Y.lvs, plsr)
     innmod <- pathmod[[1]]
     Path <- pathmod[[2]]
     R2 <- pathmod[[3]]
-    Path.efs <- pls.efects(Path)
+    Path.efs <- .pls.efects(Path)
     # ========== Stage 3: Measurement loadings and communalities =========
-    loadcomu <- pls.loads(X, Y.lvs, blocks)    
+    loadcomu <- .pls.loads(X, Y.lvs, blocks)    
     loads <- loadcomu[[1]]
     comu <- loadcomu[[2]]
     endo <- rowSums(IDM)
@@ -165,14 +161,12 @@ function(x, inner.mat, sets, modes=NULL, scheme="centroid",
     names(outmod) <- lvs.names
     names(outcor) <- lvs.names  
     # ======================== Unidimensionality =========================
-    uni.gof <- pls.unidim(DM, blocks, modes)
-    unidim <- uni.gof[[1]]# unidimensionality
-    gof.om <- uni.gof[[2]]# GoF relative outer model
+    unidim <- .pls.unidim(DM, blocks, modes)
     # ======================== Summary Inner model =======================
     exo.endo <- rowSums(IDM)
     exo.endo[rowSums(IDM)==0] <- "Exogen"
     exo.endo[rowSums(IDM)!=0] <- "Endogen"
-    av.comu <- rep(0,lvs)   # avergae communality
+    av.comu <- rep(0,lvs)   # average communality
     av.redu <- rep(0,lvs)   # average redundancy
     ave <- rep(0, lvs)      # average variance extracted
     for (k in 1:lvs)
@@ -191,30 +185,15 @@ function(x, inner.mat, sets, modes=NULL, scheme="centroid",
            R.square=round(R2,4), Av.Commu=round(av.comu,4), Av.Redun=round(av.redu,4), AVE=ave)
     rownames(innsum) <- lvs.names
     # ============================ GoF Indexes ===========================
-    gof.im <- rep(1, lvs)# GoF relative inner model
-    for (j in 1:lvs)
-    {
-        if (endo[j]==1)
-        {
-             EB <- DM[,blocklist==j]  # endog block
-             aux <- which(IDM[j,]==1)
-             SB <- DM[,which(blocklist %in% aux)]  # super block             
-             gof.im[j] <- round(cancor(EB, SB)$cor[1]^2, 4)
-        }
-    }
-    gof.abs <- pls.gof(comu, R2, blocks, IDM)
-    gof.out <- round(mean(av.comu/gof.om), 4)    
-    gof.inn <- round(sum(av.redu/gof.im)/sum(endo), 4)
-    gof.rel <- round(sqrt(gof.out*gof.inn), 4)
-    gof <- data.frame(GoF=c("Absolute", "Relative", "Outer.mod", "Inner.mod"),
-                      value=c(round(gof.abs,4), gof.rel, gof.out, gof.inn))
-    # Results
-    skem <- switch(scheme, "centroid"="centroid", "factor"="factor", "path"="path")
+    gof <- .pls.GOF(DM, IDM, blocks, comu, unidim, R2)
+    # ============================= Results ==============================
+    skem <- switch(scheme, "centroid"="centroid", "factor"="factor")
     model <- list(IDM=IDM, blocks=blocks, scheme=skem, modes=modes, scaled=scaled, 
                   boot.val=boot.val, plsr=plsr, obs=nrow(X), br=br)
-    res <- list(unidim=unidim, outer.mod=outmod, inner.mod=innmod, latents=Y.lvs, scores=Z.lvs,
-               out.weights=out.weights, loadings=loads, path.coefs=Path, r.sqr=R2, 
-               outer.cor=outcor, inner.sum=innsum, effects=Path.efs, gof=gof, data=DM, model=model)
+    res <- list(outer.mod=outmod, inner.mod=innmod, latents=Z.lvs, scores=Y.lvs,
+               out.weights=out.weights, loadings=loads, path.coefs=Path, r.sqr=R2,
+               outer.cor=outcor, inner.sum=innsum, effects=Path.efs, unidim=unidim, gof=gof, 
+               data=DM, model=model)
     # ========================= Bootstrap Validation =========================
     if (boot.val) 
     {
@@ -223,11 +202,12 @@ function(x, inner.mat, sets, modes=NULL, scheme="centroid",
         } else 
         { 
             n.efs <- nrow(Path.efs)
-            res.boot <- pls.boot(DM, IDM, blocks, modes, scheme, scaled, br, plsr)
+            res.boot <- .pls.boot(DM, IDM, blocks, modes, scheme, scaled, br, plsr)
         }
-        res <- list(unidim=unidim, outer.mod=outmod, inner.mod=innmod, latents=Y.lvs, scores=Z.lvs,
-            out.weights=out.weights, loadings=loads, path.coefs=Path, r.sqr=R2, outer.cor=outcor, 
-            inner.sum=innsum, effects=Path.efs, gof=gof, boot=res.boot, data=DM, model=model)
+        res <- list(outer.mod=outmod, inner.mod=innmod, latents=Z.lvs, scores=Y.lvs,
+                 out.weights=out.weights, loadings=loads, path.coefs=Path, r.sqr=R2,
+                 outer.cor=outcor, inner.sum=innsum, effects=Path.efs, unidim=unidim, gof=gof, 
+                 boot=res.boot, data=DM, model=model)
     } # end 'if' bootstrapping
     # --------------------------------------------------------------------
     class(res) <- "plspm"
